@@ -1,14 +1,18 @@
 """MCP tools for beads issue tracker."""
 
 import asyncio
+import logging
 import os
 import subprocess
+import sys
 from contextvars import ContextVar
 from functools import lru_cache
 from typing import Annotated, TYPE_CHECKING
 
 from .bd_client import create_bd_client, BdClientBase, BdError
 
+logger = logging.getLogger(__name__)
+
 if TYPE_CHECKING:
     from typing import List
 from .models import (
@@ -59,6 +63,50 @@ def _register_client_for_cleanup(client: BdClientBase) -> None:
         pass
 
 
+def _find_beads_db_in_tree(start_dir: str | None = None) -> str | None:
+    """Walk up directory tree looking for .beads/*.db (matches Go CLI behavior).
+    
+    Args:
+        start_dir: Starting directory (default: current working directory)
+        
+    Returns:
+        Absolute path to workspace root containing .beads/*.db, or None if not found
+    """
+    import glob
+    
+    try:
+        current = os.path.abspath(start_dir or os.getcwd())
+        
+        # Resolve symlinks like Go CLI does
+        try:
+            current = os.path.realpath(current)
+        except Exception:
+            pass
+        
+        # Walk up directory tree
+        while True:
+            beads_dir = os.path.join(current, ".beads")
+            if os.path.isdir(beads_dir):
+                # Find any .db file in .beads/ (excluding backups)
+                db_files = glob.glob(os.path.join(beads_dir, "*.db"))
+                valid_dbs = [f for f in db_files if ".backup" not in os.path.basename(f)]
+                
+                if valid_dbs:
+                    # Return workspace root (parent of .beads), not the db path
+                    return current
+            
+            parent = os.path.dirname(current)
+            if parent == current:  # Reached filesystem root
+                break
+            current = parent
+        
+        return None
+        
+    except Exception as e:
+        logger.debug(f"Failed to search for .beads in tree: {e}")
+        return None
+
+
 def _resolve_workspace_root(path: str) -> str:
     """Resolve workspace root to git repo root if inside a git repo.
     
@@ -75,10 +123,12 @@ def _resolve_workspace_root(path: str) -> str:
             capture_output=True,
             text=True,
             check=False,
+            shell=sys.platform == "win32",
         )
         if result.returncode == 0:
             return result.stdout.strip()
-    except Exception:
+    except Exception as e:
+        logger.debug(f"Git detection failed for {path}: {e}")
         pass
     
     return os.path.abspath(path)
@@ -175,8 +225,11 @@ async def _get_client() -> BdClientBase:
     """Get a BdClient instance for the current workspace.
     
     Uses connection pool to manage per-project daemon sockets.
-    Workspace is determined by current_workspace ContextVar or BEADS_WORKING_DIR env.
-
+    Workspace is auto-detected using the same logic as CLI:
+    1. current_workspace ContextVar (from workspace_root parameter)
+    2. BEADS_WORKING_DIR environment variable
+    3. Walk up from CWD looking for .beads/*.db
+    
     Performs health check before returning cached client.
     On failure, drops from pool and attempts reconnection with exponential backoff.
     
@@ -187,13 +240,23 @@ async def _get_client() -> BdClientBase:
         Configured BdClientBase instance for the current workspace
 
     Raises:
-        BdError: If no workspace is set, or bd is not installed, or version is incompatible
+        BdError: If no workspace found, or bd is not installed, or version is incompatible
     """
-    # Determine workspace from ContextVar or environment
+    # Determine workspace using standard search order (matches Go CLI)
     workspace = current_workspace.get() or os.environ.get("BEADS_WORKING_DIR")
+    
+    # Auto-detect from CWD if not explicitly set (NEW!)
+    if not workspace:
+        workspace = _find_beads_db_in_tree()
+        if workspace:
+            logger.debug(f"Auto-detected workspace from CWD: {workspace}")
+    
     if not workspace:
         raise BdError(
-            "No workspace set. Either provide workspace_root parameter or call set_context() first."
+            "No beads workspace found. Either:\n"
+            "  1. Call set_context(workspace_root=\"/path/to/project\"), OR\n"
+            "  2. Run from a directory containing .beads/, OR\n"
+            "  3. Set BEADS_WORKING_DIR environment variable"
         )
     
     # Canonicalize path to handle symlinks and deduplicate connections
@@ -478,6 +541,60 @@ async def beads_get_schema_info() -> dict:
     return await client.get_schema_info()
 
 
+async def beads_repair_deps(
+    fix: Annotated[bool, "If True, automatically remove orphaned dependencies"] = False,
+) -> dict:
+    """Find and optionally fix orphaned dependency references.
+    
+    Scans all issues for dependencies pointing to non-existent issues.
+    Returns orphaned dependencies and optionally removes them with fix=True.
+    
+    Returns dict with:
+    - orphans_found: number of orphaned dependencies
+    - orphans: list of orphaned dependency details
+    - fixed: number of orphans fixed (if fix=True)
+    """
+    client = await _get_client()
+    return await client.repair_deps(fix=fix)
+
+
+async def beads_detect_pollution(
+    clean: Annotated[bool, "If True, delete detected test issues"] = False,
+) -> dict:
+    """Detect test issues that leaked into production database.
+    
+    Detects test issues using pattern matching:
+    - Titles starting with 'test', 'benchmark', 'sample', 'tmp', 'temp'
+    - Sequential numbering (test-1, test-2, ...)
+    - Generic descriptions or no description
+    - Created in rapid succession
+    
+    Returns dict with detected test issues and deleted count if clean=True.
+    """
+    client = await _get_client()
+    return await client.detect_pollution(clean=clean)
+
+
+async def beads_validate(
+    checks: Annotated[str | None, "Comma-separated list of checks (orphans,duplicates,pollution,conflicts)"] = None,
+    fix_all: Annotated[bool, "If True, auto-fix all fixable issues"] = False,
+) -> dict:
+    """Run comprehensive database health checks.
+    
+    Available checks:
+    - orphans: Orphaned dependencies (references to deleted issues)
+    - duplicates: Duplicate issues (identical content)
+    - pollution: Test pollution (leaked test issues)
+    - conflicts: Git merge conflicts in JSONL
+    
+    If checks is None, runs all checks.
+    
+    Returns dict with validation results for each check.
+    """
+    client = await _get_client()
+    return await client.validate(checks=checks, fix_all=fix_all)
+
+
 async def beads_init(
     prefix: Annotated[str | None, "Issue prefix (e.g., 'myproject' for myproject-1, myproject-2)"] = None,
 ) -> str:
